==> bigloo1.3b.tar.gz: bigloo1.3/recette/list.scm <==
;*---------------------------------------------------------------------*/
;*    Copyright (c) 1993 by Manuel Serrano. All rights reserved.       */
;*                                                                     */
;*                                     ,--^,                           */
;*                               _ ___/ /|/                            */
;*                           ,;'( )__, ) '                             */
;*                          ;;  //   L__.                              */
;*                          '   \    /  '                              */
;*                               ^   ^                                 */
;*                                                                     */
;*                                                                     */
;*    This program is distributed in the hope that it will be useful.  */
;*    Use and copying of this software and preparation of derivative   */
;*    works based upon this software are permitted, so long as the     */
;*    following conditions are met:                                    */
;*           o credit to the authors is acknowledged following         */
;*             current academic behaviour                              */
;*           o no fees or compensation are charged for use, copies,    */
;*             or access to this software                              */
;*           o this copyright notice is included intact.               */
;*      This software is made available AS IS, and no warranty is made */
;*      about the software or its performance.                         */
;*                                                                     */
;*      Bug descriptions, use reports, comments or suggestions are     */
;*      welcome Send them to                                           */
;*        <Manuel.Serrano@inria.fr>                                    */
;*        Manuel Serrano                                               */
;*        INRIA -- Rocquencourt                                        */
;*        Domaine de Voluceau, BP 105                                  */
;*        78153 Le Chesnay Cedex                                       */
;*        France                                                       */
;*---------------------------------------------------------------------*/


;*---------------------------------------------------------------------*/
;*    serrano/prgm/project/bigloo/recette/list.scm ...                 */
;*                                                                     */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Tue Nov  3 09:21:42 1992                          */
;*    Last change :  Fri Jun 25 17:32:28 1993  (serrano)               */
;*                                                                     */
;*    On test les operations primitives sur les listes                 */
;*---------------------------------------------------------------------*/

;*---------------------------------------------------------------------*/
;*    Le module                                                        */
;*---------------------------------------------------------------------*/
(module list
   (import  (main "main.scm"))
   (include "test.sch")
   (export  (test-list)))

;*---------------------------------------------------------------------*/
;*    test-list ...                                                    */
;*---------------------------------------------------------------------*/
(define (test-list)
   (test-module "list" "list.scm" #f)
   (test "car" (car (list 1 2 3)) 1)
   (test "cdr" (cdr (list 1 2 3)) '(2 3))
   (test "set-car!" (let ((x (cons 1 2))) (set-car! x 0) x) (cons 0 2))
   (test "set-cdr!" (let ((x (cons 1 2))) (set-cdr! x 0) x) (cons 1 0))
   (test "cons" (cons 1 (cons 2 '())) '(1 2))
   (test "map" (map (lambda (x) (+ 1 x)) '(1 2 3)) '(2 3 4))
   (test "map" (map cons '(1 2 3) '(4 5 6)) '((1 . 4) (2 . 5) (3 . 6)))
   (test "map" (map list '(1 2 3) '(4 5 6)) '((1 4) (2 5) (3 6)))
   (test "map" (map (lambda (a b) (list a b)) '(1 2 3) '(4 5 6))
         '((1 4) (2 5) (3 6)))
   (test "map" (map (lambda (a b c) (list a b c)) '(1 2 3) '(4 5 6) '(7 8 9))
         '((1 4 7) (2 5 8) (3 6 9)))
   (test "map" (map (lambda (x) x) '()) '())
   (test "map" (map car '()) '())
   (test "map" (map car '((1))) '(1))
   (test "for-each" (for-each (lambda (x) x) '()) #t)
   (test "for-each" (let ((v 0))
		       (for-each (lambda (x) (set! v (+ x v)))
				 '(1 2 3))
		       v)
	 6)
   (test "for-each" (let ((v 0))
		       (for-each (lambda (x y) (set! v (+ y x v)))
				 '(1 2 3) '(4 5 6))
		       v)
	 21)
   (test "for-each" (let ((v 0))
		       (for-each (lambda (x y z) (set! v (+ y x v z)))
				 '(1 2 3) '(4 5 6) '(7 8 9))
		       v)
	 45)
   (test "reverse" (reverse '(1 2 3 4)) '(4 3 2 1))
   (test "reverse!" (reverse! '(1 2 3 4)) '(4 3 2 1))
   (test "list-tail" (list-tail '(1 2 3 4) 2) '(3 4))
   (test "list-ref" (list-ref '(1 2 (3 4) 5) 2) '(3 4))
   (test "assoc" (assoc 1 '((2 3) (4 5))) #f)
   (test "equal" (equal? '(1 2 (3 4 (5) (6 7)) (5 6) "titi"
			     #(1 2 (6 #(6 7)) titi) tutu)
			 '(1 2 (3 4 (5) (6 7)) (5 6) "titi"
			     #(1 2 (6 #(6 7)) titi) tutu))
	 #t)
   (test "equal" (equal? '(1 2 (3 4 (5) (6 7)) (5 6) "titi"
			     #(1 2 (6 #(6 7)) titi) tutu)
			 '(1 2 (3 4 (5) (6 7)) (5 6) "titi"
			     #(1 2 (6 #(6 7)) toto) tutu))
	 #f)
   (test "member" (member '(1 2 3) '((0 1 2) (1 2 3) (4 5 6)))
	 '((1 2 3) (4 5 6)))
   (test "length" (length '(1 2 3)) 3)
   (test "append" (append '(1 2 (3 4)) '((5 6) 7)) '(1 2 (3 4) (5 6) 7))
   (test "list" (list 1 2 3) '(1 2 3))
   (test "list?" (list? '(1 2 . 4)) #f)
   (test "list?" (list? '(1 2 3 4)) #t)
   (test "remq" (let ((x '(1 2 3 4))) (remq 2 x)) '(1 3 4))
   (test "remq!" (let ((x '(1 2 3 4))) (remq! 2 x) x) '(1 3 4))
   (test "remove" (let ((x '(1 2 (3 4) 5))) (remove '(3 4) x)) '(1 2 5))
   (test "remove!" (let ((x '(1 2 (3 4) 5))) (remove! '(3 4) x) x) '(1 2 5))
   (test "memq" (memq 3 '(1 2 3 4 5)) '(3 4 5))
   (test "memq" (memq #\a '(1 2 3 4 5)) #f)
   (test "member" (member '(2 3) '((1 2) (2 3) (3 4) (4 5)))
	 '((2 3) (3 4) (4 5)))
   (test "cons*" (cons* 1 0) '(1 . 0))
   (test "cons*" (cons* (cons* (quote x) 0 (quote ())) (quote ())) '((x 0))))

==> bigloo_1.8b.orig.tar.gz: bigloo-1.8b.orig/recette/list.scm <==
;*---------------------------------------------------------------------*/
;*    Copyright (c) 1996 by Manuel Serrano. All rights reserved.       */
;*                                                                     */
;*                                     ,--^,                           */
;*                               _ ___/ /|/                            */
;*                           ,;'( )__, ) '                             */
;*                          ;;  //   L__.                              */
;*                          '   \    /  '                              */
;*                               ^   ^                                 */
;*                                                                     */
;*                                                                     */
;*    This program is distributed in the hope that it will be useful.  */
;*    Use and copying of this software and preparation of derivative   */
;*    works based upon this software are permitted, so long as the     */
;*    following conditions are met:                                    */
;*           o credit to the authors is acknowledged following         */
;*             current academic behaviour                              */
;*           o no fees or compensation are charged for use, copies,    */
;*             or access to this software                              */
;*           o this copyright notice is included intact.               */
;*      This software is made available AS IS, and no warranty is made */
;*      about the software or its performance.                         */
;*                                                                     */
;*      Bug descriptions, use reports, comments or suggestions are     */
;*      welcome Send them to                                           */
;*        <Manuel.Serrano@inria.fr>                                    */
;*        Manuel Serrano                                               */
;*        INRIA -- Rocquencourt                                        */
;*        Domaine de Voluceau, BP 105                                  */
;*        78153 Le Chesnay Cedex                                       */
;*        France                                                       */
;*---------------------------------------------------------------------*/


;*---------------------------------------------------------------------*/
;*    serrano/prgm/project/bigloo/recette/list.scm ...                 */
;*                                                                     */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Tue Nov  3 09:21:42 1992                          */
;*    Last change :  Thu Dec 29 08:32:36 1994 (serrano)                */
;*                                                                     */
;*    On test les operations primitives sur les listes                 */
;*---------------------------------------------------------------------*/

;*---------------------------------------------------------------------*/
;*    Le module                                                        */
;*---------------------------------------------------------------------*/
(module list
   (import  (main "main.scm"))
   (include "test.sch")
   (export  (test-list)))
 
;*---------------------------------------------------------------------*/
;*    test-list ...                                                    */
;*---------------------------------------------------------------------*/
(define (test-list)
   (test-module "list" "list.scm" #f)
   (test "car" (car (list 1 2 3)) 1)
   (test "cdr" (cdr (list 1 2 3)) '(2 3))
   (test "set-car!" (let ((x (cons 1 2))) (set-car! x 0) x) (cons 0 2))
   (test "set-cdr!" (let ((x (cons 1 2))) (set-cdr! x 0) x) (cons 1 0))
   (test "cons" (cons 1 (cons 2 '())) '(1 2))
   (test "epair" (epair? (econs 1 2 3)) #t)
   (test "epair" (pair? (econs 1 2 3)) #t)
   (test "epair" (cer (econs 1 2 3)) 3)
   (test "epair" (let ((p (econs 1 2 3)))
		    (set-cer! p 4)
		    (cer p))
	 4)
   (test "epair" (car (econs 1 2 3)) 1)
   (test "epair" (cdr (econs 1 2 3)) 2)
   (test "map" (map (lambda (x) (+ 1 x)) '(1 2 3)) '(2 3 4))
   (test "map" (map cons '(1 2 3) '(4 5 6)) '((1 . 4) (2 . 5) (3 . 6)))
   (test "map" (map list '(1 2 3) '(4 5 6)) '((1 4) (2 5) (3 6)))
   (test "map" (map (lambda (a b) (list a b)) '(1 2 3) '(4 5 6))
         '((1 4) (2 5) (3 6)))
   (test "map" (map (lambda (a b c) (list a b c)) '(1 2 3) '(4 5 6) '(7 8 9))
         '((1 4 7) (2 5 8) (3 6 9)))
   (test "map" (map (lambda (x) x) '()) '())
   (test "map" (map car '()) '())
   (test "map" (map car '((1))) '(1))
   (test "for-each" (for-each (lambda (x) x) '()) #t) 
   (test "for-each" (let ((v 0))
		       (for-each (lambda (x) (set! v (+ x v)))
				 '(1 2 3))
		       v)
	 6)
   (test "for-each" (let ((v 0))
		       (for-each (lambda (x y) (set! v (+ y x v)))
				 '(1 2 3) '(4 5 6))
		       v)
	 21)
   (test "for-each" (let ((v 0))
		       (for-each (lambda (x y z) (set! v (+ y x v z)))
				 '(1 2 3) '(4 5 6) '(7 8 9))
		       v)
	 45)
   (test "reverse" (reverse '(1 2 3 4)) '(4 3 2 1))
   (test "reverse!" (reverse! '(1 2 3 4)) '(4 3 2 1))
   (test "list-tail" (list-tail '(1 2 3 4) 2) '(3 4))
   (test "list-ref" (list-ref '(1 2 (3 4) 5) 2) '(3 4))
   (test "assoc" (assoc 1 '((2 3) (4 5))) #f)
   (test "equal" (equal? '(1 2 (3 4 (5) (6 7)) (5 6) "titi"
			     #(1 2 (6 #(6 7)) titi) tutu)
			 '(1 2 (3 4 (5) (6 7)) (5 6) "titi"
			     #(1 2 (6 #(6 7)) titi) tutu))
	 #t)
   (test "equal" (equal? '(1 2 (3 4 (5) (6 7)) (5 6) "titi"
			     #(1 2 (6 #(6 7)) titi) tutu)
			 '(1 2 (3 4 (5) (6 7)) (5 6) "titi"
			     #(1 2 (6 #(6 7)) toto) tutu))
	 #f)
   (test "member" (member '(1 2 3) '((0 1 2) (1 2 3) (4 5 6)))
	 '((1 2 3) (4 5 6)))
   (test "length" (length '(1 2 3)) 3)
   (test "append" (append '(1 2 (3 4)) '((5 6) 7)) '(1 2 (3 4) (5 6) 7))
   (test "list" (list 1 2 3) '(1 2 3))
   (test "list?" (list? '(1 2 . 4)) #f)
   (test "list?" (list? '(1 2 3 4)) #t)
   (test "remq" (let ((x '(1 2 3 4))) (remq 2 x)) '(1 3 4))
   (test "remq!" (let ((x '(1 2 3 4))) (remq! 2 x) x) '(1 3 4))
   (test "remove" (let ((x '(1 2 (3 4) 5))) (remove '(3 4) x)) '(1 2 5))
   (test "remove!" (let ((x '(1 2 (3 4) 5))) (remove! '(3 4) x) x) '(1 2 5))
   (test "memq" (memq 3 '(1 2 3 4 5)) '(3 4 5))
   (test "memq" (memq #\a '(1 2 3 4 5)) #f)
   (test "member" (member '(2 3) '((1 2) (2 3) (3 4) (4 5)))
	 '((2 3) (3 4) (4 5)))
   (test "cons*" (cons* 1 0) '(1 . 0))
   (test "cons*" (cons* (cons* (quote x) 0 (quote ())) (quote ())) '((x 0))))
